@@ -13,20 +13,13 @@ test_that("train_esn function works correctly", {
   
   # Test if the function output is of class "esn"
   expect_true(class(esn_model) == "esn")
+  expect_true(is.esn(esn_model))
   
-  # Test if the residuals vector has the same length as the input vector
+  # Test object lengths and dimensions
   expect_equal(length(esn_model$actual), length(ytrain))
-  
-  # Test if the residuals vector has the same length as the input vector
   expect_equal(length(esn_model$fitted), length(ytrain))
-  
-  # Test if the residuals vector has the same length as the input vector
   expect_equal(length(esn_model$resid), length(ytrain))
-  
-  # Test if the actual and fitted vectors have the same length
   expect_equal(length(esn_model$actual), length(esn_model$fitted))
-  
-  # Test if the actual and fitted vectors have the same length
   expect_equal(length(esn_model$resid), length(esn_model$fitted))
   
   # Test if the model_weights list contains the expected elements
@@ -35,8 +28,6 @@ test_that("train_esn function works correctly", {
   # Test if n_states is as expected
   expect_equal(esn_model$method$model_layers$n_states, 50)
   
-  # Test of n_models is as expected
+  # Test if n_models is as expected
   expect_equal(esn_model$method$model_meta$n_models, 100)
-  
-  # Add more tests as needed...
 })
